@@ -3,7 +3,6 @@ from .proxies import BaseProxy
 from .proxies.project import ProjectProxy
 from .proxies.build import BuildProxy
 from .proxies.package import PackageProxy
-from .proxies.module import ModuleProxy
 from .proxies.mock_chroot import MockChrootProxy
 from .proxies.monitor import MonitorProxy
 from .proxies.project_chroot import ProjectChrootProxy
@@ -18,7 +17,6 @@ class Client(object):
         self.project_proxy = ProjectProxy(config)
         self.build_proxy = BuildProxy(config)
         self.package_proxy = PackageProxy(config)
-        self.module_proxy = ModuleProxy(config)
         self.mock_chroot_proxy = MockChrootProxy(config)
         self.monitor_proxy = MonitorProxy(config)
         self.project_chroot_proxy = ProjectChrootProxy(config)
